/////////////////////////////////////////////////////////////////////
//
//            X   X           X
//           XXX XX         XX
//          XXXXXXXX      XXX
//         XX X XXXXXXXXXXX
//        XXXXX XXXXXXXXX
//       XXXXX XXXXXXXXXX
//            XXX XXX XXX
//           XXX XX   XX
//           X   X     X
//
//    Copyright (C) 2003-2021  Ron Jakl
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
/////////////////////////////////////////////////////////////////////


#ifndef LENGTHCOMPAREHEADERFILE
#define LENGTHCOMPAREHEADERFILE

#include <QDialog>

class QFrame;
class QPushButton;
class QWidget;
class QCloseEvent;
class QDragEnterEvent;
class QDropEvent;

class TGraphWidget;
class TEntryWidget;
class TXmlFile;
class TMessageBox;

class TLengthCompare : public QDialog
{
Q_OBJECT

public:

// CREATORS
	TLengthCompare(const QWidget *parent=0, Qt::WindowFlags flags=0);
	virtual ~TLengthCompare(void);

// ACCESSORS
	bool Save_Data(const QString &file_name) const;
	bool Export_Data(const QString &file_name);

// MANIPULATORS
	bool Load_Data(const QString &file_name);

signals:

private slots:
	void Entry_Data_Changed(void);
	
	void Load(void);
	void Save(void);
	void Export(void);
	
protected:
	virtual void closeEvent(QCloseEvent *event);
	virtual void dragEnterEvent(QDragEnterEvent *event);
	virtual void dropEvent(QDropEvent *event);
	
private:
	TEntryWidget						*d_entry_a_widget;
	TEntryWidget						*d_entry_b_widget;
	QPushButton							*d_close_button;
	QPushButton							*d_load_button;
	QPushButton							*d_save_button;
	QPushButton							*d_export_button;
	TGraphWidget						*d_graph_data_widget;
	TGraphWidget						*d_graph_en_widget;
	TMessageBox							*d_message_box;

	std::vector<double>					d_graph_positions;
	QString								d_current_file_name;
	bool								d_data_changed;
	
	mutable QString						d_last_error;
	
	void Add_Graph_Position(const double &position);
	void Load_Data_V1(TXmlFile * const xml_file);

	void Generate_Test_Data(void);

// NOT IMPLEMENTED
	TLengthCompare(const TLengthCompare&);
	TLengthCompare& operator=(const TLengthCompare&);
};

#endif
